# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_object import UntypedStripeObject
from typing import Dict, List
from typing_extensions import Literal, NotRequired, TypedDict


class DisputeUpdateParams(TypedDict):
    evidence: NotRequired["DisputeUpdateParamsEvidence"]
    """
    Evidence to upload, to respond to a dispute. Updating any field in the hash will submit all fields in the hash for review. The combined character count of all fields is limited to 150,000.
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    metadata: NotRequired[
        "Literal['']|Dict[str, str]|UntypedStripeObject[str]"
    ]
    """
    Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.
    """
    submit: NotRequired[bool]
    """
    Whether to immediately submit evidence to the bank. If `false`, evidence is staged on the dispute. Staged evidence is visible in the API and Dashboard, and can be submitted to the bank by making another request with this attribute set to `true` (the default).
    """


class DisputeUpdateParamsEvidence(TypedDict):
    access_activity_log: NotRequired[str]
    """
    Any server or activity logs showing proof that the customer accessed or downloaded the purchased digital product. This information should include IP addresses, corresponding timestamps, and any detailed recorded activity. Has a maximum character count of 20,000.
    """
    billing_address: NotRequired[str]
    """
    The billing address provided by the customer.
    """
    cancellation_policy: NotRequired[str]
    """
    (ID of a [file upload](https://stripe.com/docs/guides/file-upload)) Your subscription cancellation policy, as shown to the customer.
    """
    cancellation_policy_disclosure: NotRequired[str]
    """
    An explanation of how and when the customer was shown your refund policy prior to purchase. Has a maximum character count of 20,000.
    """
    cancellation_rebuttal: NotRequired[str]
    """
    A justification for why the customer's subscription was not canceled. Has a maximum character count of 20,000.
    """
    customer_communication: NotRequired[str]
    """
    (ID of a [file upload](https://stripe.com/docs/guides/file-upload)) Any communication with the customer that you feel is relevant to your case. Examples include emails proving that the customer received the product or service, or demonstrating their use of or satisfaction with the product or service.
    """
    customer_email_address: NotRequired[str]
    """
    The email address of the customer.
    """
    customer_name: NotRequired[str]
    """
    The name of the customer.
    """
    customer_purchase_ip: NotRequired[str]
    """
    The IP address that the customer used when making the purchase.
    """
    customer_signature: NotRequired[str]
    """
    (ID of a [file upload](https://stripe.com/docs/guides/file-upload)) A relevant document or contract showing the customer's signature.
    """
    duplicate_charge_documentation: NotRequired[str]
    """
    (ID of a [file upload](https://stripe.com/docs/guides/file-upload)) Documentation for the prior charge that can uniquely identify the charge, such as a receipt, shipping label, work order, etc. This document should be paired with a similar document from the disputed payment that proves the two payments are separate.
    """
    duplicate_charge_explanation: NotRequired[str]
    """
    An explanation of the difference between the disputed charge versus the prior charge that appears to be a duplicate. Has a maximum character count of 20,000.
    """
    duplicate_charge_id: NotRequired[str]
    """
    The Stripe ID for the prior charge which appears to be a duplicate of the disputed charge.
    """
    enhanced_evidence: NotRequired[
        "Literal['']|DisputeUpdateParamsEvidenceEnhancedEvidence"
    ]
    """
    Additional evidence for qualifying evidence programs.
    """
    product_description: NotRequired[str]
    """
    A description of the product or service that was sold. Has a maximum character count of 20,000.
    """
    receipt: NotRequired[str]
    """
    (ID of a [file upload](https://stripe.com/docs/guides/file-upload)) Any receipt or message sent to the customer notifying them of the charge.
    """
    refund_policy: NotRequired[str]
    """
    (ID of a [file upload](https://stripe.com/docs/guides/file-upload)) Your refund policy, as shown to the customer.
    """
    refund_policy_disclosure: NotRequired[str]
    """
    Documentation demonstrating that the customer was shown your refund policy prior to purchase. Has a maximum character count of 20,000.
    """
    refund_refusal_explanation: NotRequired[str]
    """
    A justification for why the customer is not entitled to a refund. Has a maximum character count of 20,000.
    """
    service_date: NotRequired[str]
    """
    The date on which the customer received or began receiving the purchased service, in a clear human-readable format.
    """
    service_documentation: NotRequired[str]
    """
    (ID of a [file upload](https://stripe.com/docs/guides/file-upload)) Documentation showing proof that a service was provided to the customer. This could include a copy of a signed contract, work order, or other form of written agreement.
    """
    shipping_address: NotRequired[str]
    """
    The address to which a physical product was shipped. You should try to include as complete address information as possible.
    """
    shipping_carrier: NotRequired[str]
    """
    The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc. If multiple carriers were used for this purchase, please separate them with commas.
    """
    shipping_date: NotRequired[str]
    """
    The date on which a physical product began its route to the shipping address, in a clear human-readable format.
    """
    shipping_documentation: NotRequired[str]
    """
    (ID of a [file upload](https://stripe.com/docs/guides/file-upload)) Documentation showing proof that a product was shipped to the customer at the same address the customer provided to you. This could include a copy of the shipment receipt, shipping label, etc. It should show the customer's full shipping address, if possible.
    """
    shipping_tracking_number: NotRequired[str]
    """
    The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
    """
    uncategorized_file: NotRequired[str]
    """
    (ID of a [file upload](https://stripe.com/docs/guides/file-upload)) Any additional evidence or statements.
    """
    uncategorized_text: NotRequired[str]
    """
    Any additional evidence or statements. Has a maximum character count of 20,000.
    """


class DisputeUpdateParamsEvidenceEnhancedEvidence(TypedDict):
    mastercard_compliance: NotRequired[
        "DisputeUpdateParamsEvidenceEnhancedEvidenceMastercardCompliance"
    ]
    """
    Evidence provided for Mastercard compliance evidence submission.
    """
    visa_compelling_evidence_3: NotRequired[
        "DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3"
    ]
    """
    Evidence provided for Visa Compelling Evidence 3.0 evidence submission.
    """
    visa_compliance: NotRequired[
        "DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompliance"
    ]
    """
    Evidence provided for Visa compliance evidence submission.
    """


class DisputeUpdateParamsEvidenceEnhancedEvidenceMastercardCompliance(
    TypedDict,
):
    fee_acknowledged: NotRequired[bool]
    """
    A field acknowledging the fee incurred when countering a Mastercard compliance dispute. If this field is set to true, evidence can be submitted for the compliance dispute.
    """


class DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3(
    TypedDict,
):
    disputed_transaction: NotRequired[
        "DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransaction"
    ]
    """
    Disputed transaction details for Visa Compelling Evidence 3.0 evidence submission.
    """
    prior_undisputed_transactions: NotRequired[
        List[
            "DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransaction"
        ]
    ]
    """
    List of exactly two prior undisputed transaction objects for Visa Compelling Evidence 3.0 evidence submission.
    """


class DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransaction(
    TypedDict,
):
    customer_account_id: NotRequired["Literal['']|str"]
    """
    User Account ID used to log into business platform. Must be recognizable by the user.
    """
    customer_device_fingerprint: NotRequired["Literal['']|str"]
    """
    Unique identifier of the cardholder's device derived from a combination of at least two hardware and software attributes. Must be at least 20 characters.
    """
    customer_device_id: NotRequired["Literal['']|str"]
    """
    Unique identifier of the cardholder's device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]). Must be at least 15 characters.
    """
    customer_email_address: NotRequired["Literal['']|str"]
    """
    The email address of the customer.
    """
    customer_purchase_ip: NotRequired["Literal['']|str"]
    """
    The IP address that the customer used when making the purchase.
    """
    merchandise_or_services: NotRequired[
        "Literal['merchandise', 'services']|str"
    ]
    """
    Categorization of disputed payment.
    """
    product_description: NotRequired["Literal['']|str"]
    """
    A description of the product or service that was sold.
    """
    shipping_address: NotRequired[
        "DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransactionShippingAddress"
    ]
    """
    The address to which a physical product was shipped. All fields are required for Visa Compelling Evidence 3.0 evidence submission.
    """


class DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransactionShippingAddress(
    TypedDict,
):
    city: NotRequired["Literal['']|str"]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired["Literal['']|str"]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired["Literal['']|str"]
    """
    Address line 1, such as the street, PO Box, or company name.
    """
    line2: NotRequired["Literal['']|str"]
    """
    Address line 2, such as the apartment, suite, unit, or building.
    """
    postal_code: NotRequired["Literal['']|str"]
    """
    ZIP or postal code.
    """
    state: NotRequired["Literal['']|str"]
    """
    State, county, province, or region ([ISO 3166-2](https://en.wikipedia.org/wiki/ISO_3166-2)).
    """


class DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransaction(
    TypedDict,
):
    charge: str
    """
    Stripe charge ID for the Visa Compelling Evidence 3.0 eligible prior charge.
    """
    customer_account_id: NotRequired["Literal['']|str"]
    """
    User Account ID used to log into business platform. Must be recognizable by the user.
    """
    customer_device_fingerprint: NotRequired["Literal['']|str"]
    """
    Unique identifier of the cardholder's device derived from a combination of at least two hardware and software attributes. Must be at least 20 characters.
    """
    customer_device_id: NotRequired["Literal['']|str"]
    """
    Unique identifier of the cardholder's device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]). Must be at least 15 characters.
    """
    customer_email_address: NotRequired["Literal['']|str"]
    """
    The email address of the customer.
    """
    customer_purchase_ip: NotRequired["Literal['']|str"]
    """
    The IP address that the customer used when making the purchase.
    """
    product_description: NotRequired["Literal['']|str"]
    """
    A description of the product or service that was sold.
    """
    shipping_address: NotRequired[
        "DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransactionShippingAddress"
    ]
    """
    The address to which a physical product was shipped. All fields are required for Visa Compelling Evidence 3.0 evidence submission.
    """


class DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransactionShippingAddress(
    TypedDict,
):
    city: NotRequired["Literal['']|str"]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired["Literal['']|str"]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired["Literal['']|str"]
    """
    Address line 1, such as the street, PO Box, or company name.
    """
    line2: NotRequired["Literal['']|str"]
    """
    Address line 2, such as the apartment, suite, unit, or building.
    """
    postal_code: NotRequired["Literal['']|str"]
    """
    ZIP or postal code.
    """
    state: NotRequired["Literal['']|str"]
    """
    State, county, province, or region ([ISO 3166-2](https://en.wikipedia.org/wiki/ISO_3166-2)).
    """


class DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompliance(TypedDict):
    fee_acknowledged: NotRequired[bool]
    """
    A field acknowledging the fee incurred when countering a Visa compliance dispute. If this field is set to true, evidence can be submitted for the compliance dispute. Stripe collects a 500 USD (or local equivalent) amount to cover the network costs associated with resolving compliance disputes. Stripe refunds the 500 USD network fee if you win the dispute.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._credit_note import CreditNote
    from stripe._credit_note_line_item_service import CreditNoteLineItemService
    from stripe._credit_note_preview_lines_service import (
        CreditNotePreviewLinesService,
    )
    from stripe._list_object import ListObject
    from stripe._request_options import RequestOptions
    from stripe.params._credit_note_create_params import CreditNoteCreateParams
    from stripe.params._credit_note_list_params import CreditNoteListParams
    from stripe.params._credit_note_preview_params import (
        CreditNotePreviewParams,
    )
    from stripe.params._credit_note_retrieve_params import (
        CreditNoteRetrieveParams,
    )
    from stripe.params._credit_note_update_params import CreditNoteUpdateParams
    from stripe.params._credit_note_void_credit_note_params import (
        CreditNoteVoidCreditNoteParams,
    )

_subservices = {
    "line_items": [
        "stripe._credit_note_line_item_service",
        "CreditNoteLineItemService",
    ],
    "preview_lines": [
        "stripe._credit_note_preview_lines_service",
        "CreditNotePreviewLinesService",
    ],
}


class CreditNoteService(StripeService):
    line_items: "CreditNoteLineItemService"
    preview_lines: "CreditNotePreviewLinesService"

    def __init__(self, requestor):
        super().__init__(requestor)

    def __getattr__(self, name):
        try:
            import_from, service = _subservices[name]
            service_class = getattr(
                import_module(import_from),
                service,
            )
            setattr(
                self,
                name,
                service_class(self._requestor),
            )
            return getattr(self, name)
        except KeyError:
            raise AttributeError()

    def list(
        self,
        params: Optional["CreditNoteListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[CreditNote]":
        """
        Returns a list of credit notes.
        """
        return cast(
            "ListObject[CreditNote]",
            self._request(
                "get",
                "/v1/credit_notes",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["CreditNoteListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[CreditNote]":
        """
        Returns a list of credit notes.
        """
        return cast(
            "ListObject[CreditNote]",
            await self._request_async(
                "get",
                "/v1/credit_notes",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def create(
        self,
        params: "CreditNoteCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "CreditNote":
        """
        Issue a credit note to adjust the amount of a finalized invoice. A credit note will first reduce the invoice's amount_remaining (and amount_due), but not below zero.
        This amount is indicated by the credit note's pre_payment_amount. The excess amount is indicated by post_payment_amount, and it can result in any combination of the following:


        Refunds: create a new refund (using refund_amount) or link existing refunds (using refunds).
        Customer balance credit: credit the customer's balance (using credit_amount) which will be automatically applied to their next invoice when it's finalized.
        Outside of Stripe credit: record the amount that is or will be credited outside of Stripe (using out_of_band_amount).


        The sum of refunds, customer balance credits, and outside of Stripe credits must equal the post_payment_amount.

        You may issue multiple credit notes for an invoice. Each credit note may increment the invoice's pre_payment_credit_notes_amount,
        post_payment_credit_notes_amount, or both, depending on the invoice's amount_remaining at the time of credit note creation.

        For invoices that also have refunds created through the [Refund API](https://docs.stripe.com/docs/api/refunds), the credit note API subtracts those refund amounts from the maximum creditable amount. This prevents the combined credit notes and refunds from exceeding the invoice amount. If you use both, ensure the combined total does not exceed the invoice's paid amount.
        """
        return cast(
            "CreditNote",
            self._request(
                "post",
                "/v1/credit_notes",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: "CreditNoteCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "CreditNote":
        """
        Issue a credit note to adjust the amount of a finalized invoice. A credit note will first reduce the invoice's amount_remaining (and amount_due), but not below zero.
        This amount is indicated by the credit note's pre_payment_amount. The excess amount is indicated by post_payment_amount, and it can result in any combination of the following:


        Refunds: create a new refund (using refund_amount) or link existing refunds (using refunds).
        Customer balance credit: credit the customer's balance (using credit_amount) which will be automatically applied to their next invoice when it's finalized.
        Outside of Stripe credit: record the amount that is or will be credited outside of Stripe (using out_of_band_amount).


        The sum of refunds, customer balance credits, and outside of Stripe credits must equal the post_payment_amount.

        You may issue multiple credit notes for an invoice. Each credit note may increment the invoice's pre_payment_credit_notes_amount,
        post_payment_credit_notes_amount, or both, depending on the invoice's amount_remaining at the time of credit note creation.

        For invoices that also have refunds created through the [Refund API](https://docs.stripe.com/docs/api/refunds), the credit note API subtracts those refund amounts from the maximum creditable amount. This prevents the combined credit notes and refunds from exceeding the invoice amount. If you use both, ensure the combined total does not exceed the invoice's paid amount.
        """
        return cast(
            "CreditNote",
            await self._request_async(
                "post",
                "/v1/credit_notes",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        id: str,
        params: Optional["CreditNoteRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "CreditNote":
        """
        Retrieves the credit note object with the given identifier.
        """
        return cast(
            "CreditNote",
            self._request(
                "get",
                "/v1/credit_notes/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        id: str,
        params: Optional["CreditNoteRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "CreditNote":
        """
        Retrieves the credit note object with the given identifier.
        """
        return cast(
            "CreditNote",
            await self._request_async(
                "get",
                "/v1/credit_notes/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def update(
        self,
        id: str,
        params: Optional["CreditNoteUpdateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "CreditNote":
        """
        Updates an existing credit note.
        """
        return cast(
            "CreditNote",
            self._request(
                "post",
                "/v1/credit_notes/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def update_async(
        self,
        id: str,
        params: Optional["CreditNoteUpdateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "CreditNote":
        """
        Updates an existing credit note.
        """
        return cast(
            "CreditNote",
            await self._request_async(
                "post",
                "/v1/credit_notes/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def preview(
        self,
        params: "CreditNotePreviewParams",
        options: Optional["RequestOptions"] = None,
    ) -> "CreditNote":
        """
        Get a preview of a credit note without creating it.
        """
        return cast(
            "CreditNote",
            self._request(
                "get",
                "/v1/credit_notes/preview",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def preview_async(
        self,
        params: "CreditNotePreviewParams",
        options: Optional["RequestOptions"] = None,
    ) -> "CreditNote":
        """
        Get a preview of a credit note without creating it.
        """
        return cast(
            "CreditNote",
            await self._request_async(
                "get",
                "/v1/credit_notes/preview",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def void_credit_note(
        self,
        id: str,
        params: Optional["CreditNoteVoidCreditNoteParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "CreditNote":
        """
        Marks a credit note as void. Learn more about [voiding credit notes](https://docs.stripe.com/docs/billing/invoices/credit-notes#voiding).
        """
        return cast(
            "CreditNote",
            self._request(
                "post",
                "/v1/credit_notes/{id}/void".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def void_credit_note_async(
        self,
        id: str,
        params: Optional["CreditNoteVoidCreditNoteParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "CreditNote":
        """
        Marks a credit note as void. Learn more about [voiding credit notes](https://docs.stripe.com/docs/billing/invoices/credit-notes#voiding).
        """
        return cast(
            "CreditNote",
            await self._request_async(
                "post",
                "/v1/credit_notes/{id}/void".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._request_options import RequestOptions
    from stripe.params.test_helpers.treasury._received_credit_create_params import (
        ReceivedCreditCreateParams,
    )
    from stripe.treasury._received_credit import ReceivedCredit


class ReceivedCreditService(StripeService):
    def create(
        self,
        params: "ReceivedCreditCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "ReceivedCredit":
        """
        Use this endpoint to simulate a test mode ReceivedCredit initiated by a third party. In live mode, you can't directly create ReceivedCredits initiated by third parties.
        """
        return cast(
            "ReceivedCredit",
            self._request(
                "post",
                "/v1/test_helpers/treasury/received_credits",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: "ReceivedCreditCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "ReceivedCredit":
        """
        Use this endpoint to simulate a test mode ReceivedCredit initiated by a third party. In live mode, you can't directly create ReceivedCredits initiated by third parties.
        """
        return cast(
            "ReceivedCredit",
            await self._request_async(
                "post",
                "/v1/test_helpers/treasury/received_credits",
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._createable_api_resource import CreateableAPIResource
from stripe._stripe_object import UntypedStripeObject
from typing import ClassVar, cast
from typing_extensions import Literal, Unpack, TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.billing._meter_event_create_params import (
        MeterEventCreateParams,
    )


class MeterEvent(CreateableAPIResource["MeterEvent"]):
    """
    Meter events represent actions that customers take in your system. You can use meter events to bill a customer based on their usage. Meter events are associated with billing meters, which define both the contents of the event's payload and how to aggregate those events.
    """

    OBJECT_NAME: ClassVar[Literal["billing.meter_event"]] = (
        "billing.meter_event"
    )
    created: int
    """
    Time at which the object was created. Measured in seconds since the Unix epoch.
    """
    event_name: str
    """
    The name of the meter event. Corresponds with the `event_name` field on a meter.
    """
    identifier: str
    """
    A unique identifier for the event.
    """
    livemode: bool
    """
    If the object exists in live mode, the value is `true`. If the object exists in test mode, the value is `false`.
    """
    object: Literal["billing.meter_event"]
    """
    String representing the object's type. Objects of the same type share the same value.
    """
    payload: UntypedStripeObject[str]
    """
    The payload of the event. This contains the fields corresponding to a meter's `customer_mapping.event_payload_key` (default is `stripe_customer_id`) and `value_settings.event_payload_key` (default is `value`). Read more about the [payload](https://docs.stripe.com/billing/subscriptions/usage-based/meters/configure#meter-configuration-attributes).
    """
    timestamp: int
    """
    The timestamp passed in when creating the event. Measured in seconds since the Unix epoch.
    """

    @classmethod
    def create(
        cls, **params: Unpack["MeterEventCreateParams"]
    ) -> "MeterEvent":
        """
        Creates a billing meter event.
        """
        return cast(
            "MeterEvent",
            cls._static_request(
                "post",
                cls.class_url(),
                params=params,
            ),
        )

    @classmethod
    async def create_async(
        cls, **params: Unpack["MeterEventCreateParams"]
    ) -> "MeterEvent":
        """
        Creates a billing meter event.
        """
        return cast(
            "MeterEvent",
            await cls._static_request_async(
                "post",
                cls.class_url(),
                params=params,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._createable_api_resource import CreateableAPIResource
from stripe._deletable_api_resource import DeletableAPIResource
from stripe._expandable_field import ExpandableField
from stripe._list_object import ListObject
from stripe._listable_api_resource import ListableAPIResource
from stripe._stripe_object import StripeObject
from stripe._updateable_api_resource import UpdateableAPIResource
from stripe._util import class_method_variant, sanitize_id
from typing import ClassVar, List, Optional, Union, cast, overload
from typing_extensions import Literal, Unpack, TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._file import File
    from stripe.params.terminal._configuration_create_params import (
        ConfigurationCreateParams,
    )
    from stripe.params.terminal._configuration_delete_params import (
        ConfigurationDeleteParams,
    )
    from stripe.params.terminal._configuration_list_params import (
        ConfigurationListParams,
    )
    from stripe.params.terminal._configuration_modify_params import (
        ConfigurationModifyParams,
    )
    from stripe.params.terminal._configuration_retrieve_params import (
        ConfigurationRetrieveParams,
    )


class Configuration(
    CreateableAPIResource["Configuration"],
    DeletableAPIResource["Configuration"],
    ListableAPIResource["Configuration"],
    UpdateableAPIResource["Configuration"],
):
    """
    A Configurations object represents how features should be configured for terminal readers.
    For information about how to use it, see the [Terminal configurations documentation](https://docs.stripe.com/terminal/fleet/configurations-overview).
    """

    OBJECT_NAME: ClassVar[Literal["terminal.configuration"]] = (
        "terminal.configuration"
    )

    class BbposWisepad3(StripeObject):
        splashscreen: Optional[ExpandableField["File"]]
        """
        A File ID representing an image to display on the reader
        """

    class BbposWiseposE(StripeObject):
        splashscreen: Optional[ExpandableField["File"]]
        """
        A File ID representing an image to display on the reader
        """

    class Cellular(StripeObject):
        enabled: bool
        """
        Whether a cellular-capable reader can connect to the internet over cellular.
        """

    class Offline(StripeObject):
        enabled: Optional[bool]
        """
        Determines whether to allow transactions to be collected while reader is offline. Defaults to false.
        """

    class RebootWindow(StripeObject):
        end_hour: int
        """
        Integer between 0 to 23 that represents the end hour of the reboot time window. The value must be different than the start_hour.
        """
        start_hour: int
        """
        Integer between 0 to 23 that represents the start hour of the reboot time window.
        """

    class StripeS700(StripeObject):
        splashscreen: Optional[ExpandableField["File"]]
        """
        A File ID representing an image to display on the reader
        """

    class StripeS710(StripeObject):
        splashscreen: Optional[ExpandableField["File"]]
        """
        A File ID representing an image to display on the reader
        """

    class Tipping(StripeObject):
        class Aed(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Aud(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Cad(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Chf(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Czk(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Dkk(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Eur(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Gbp(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Gip(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Hkd(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Huf(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Jpy(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Mxn(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Myr(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Nok(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Nzd(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Pln(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Ron(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Sek(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Sgd(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        class Usd(StripeObject):
            fixed_amounts: Optional[List[int]]
            """
            Fixed amounts displayed when collecting a tip
            """
            percentages: Optional[List[int]]
            """
            Percentages displayed when collecting a tip
            """
            smart_tip_threshold: Optional[int]
            """
            Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
            """

        aed: Optional[Aed]
        aud: Optional[Aud]
        cad: Optional[Cad]
        chf: Optional[Chf]
        czk: Optional[Czk]
        dkk: Optional[Dkk]
        eur: Optional[Eur]
        gbp: Optional[Gbp]
        gip: Optional[Gip]
        hkd: Optional[Hkd]
        huf: Optional[Huf]
        jpy: Optional[Jpy]
        mxn: Optional[Mxn]
        myr: Optional[Myr]
        nok: Optional[Nok]
        nzd: Optional[Nzd]
        pln: Optional[Pln]
        ron: Optional[Ron]
        sek: Optional[Sek]
        sgd: Optional[Sgd]
        usd: Optional[Usd]
        _inner_class_types = {
            "aed": Aed,
            "aud": Aud,
            "cad": Cad,
            "chf": Chf,
            "czk": Czk,
            "dkk": Dkk,
            "eur": Eur,
            "gbp": Gbp,
            "gip": Gip,
            "hkd": Hkd,
            "huf": Huf,
            "jpy": Jpy,
            "mxn": Mxn,
            "myr": Myr,
            "nok": Nok,
            "nzd": Nzd,
            "pln": Pln,
            "ron": Ron,
            "sek": Sek,
            "sgd": Sgd,
            "usd": Usd,
        }

    class VerifoneM425(StripeObject):
        splashscreen: Optional[ExpandableField["File"]]
        """
        A File ID representing an image to display on the reader
        """

    class VerifoneP400(StripeObject):
        splashscreen: Optional[ExpandableField["File"]]
        """
        A File ID representing an image to display on the reader
        """

    class VerifoneP630(StripeObject):
        splashscreen: Optional[ExpandableField["File"]]
        """
        A File ID representing an image to display on the reader
        """

    class VerifoneUx700(StripeObject):
        splashscreen: Optional[ExpandableField["File"]]
        """
        A File ID representing an image to display on the reader
        """

    class VerifoneV660p(StripeObject):
        splashscreen: Optional[ExpandableField["File"]]
        """
        A File ID representing an image to display on the reader
        """

    class Wifi(StripeObject):
        class EnterpriseEapPeap(StripeObject):
            ca_certificate_file: Optional[str]
            """
            A File ID representing a PEM file containing the server certificate
            """
            password: str
            """
            Password for connecting to the WiFi network
            """
            ssid: str
            """
            Name of the WiFi network
            """
            username: str
            """
            Username for connecting to the WiFi network
            """

        class EnterpriseEapTls(StripeObject):
            ca_certificate_file: Optional[str]
            """
            A File ID representing a PEM file containing the server certificate
            """
            client_certificate_file: str
            """
            A File ID representing a PEM file containing the client certificate
            """
            private_key_file: str
            """
            A File ID representing a PEM file containing the client RSA private key
            """
            private_key_file_password: Optional[str]
            """
            Password for the private key file
            """
            ssid: str
            """
            Name of the WiFi network
            """

        class PersonalPsk(StripeObject):
            password: str
            """
            Password for connecting to the WiFi network
            """
            ssid: str
            """
            Name of the WiFi network
            """

        enterprise_eap_peap: Optional[EnterpriseEapPeap]
        enterprise_eap_tls: Optional[EnterpriseEapTls]
        personal_psk: Optional[PersonalPsk]
        type: Union[
            Literal[
                "enterprise_eap_peap", "enterprise_eap_tls", "personal_psk"
            ],
            str,
        ]
        """
        Security type of the WiFi network. The hash with the corresponding name contains the credentials for this security type.
        """
        _inner_class_types = {
            "enterprise_eap_peap": EnterpriseEapPeap,
            "enterprise_eap_tls": EnterpriseEapTls,
            "personal_psk": PersonalPsk,
        }

    bbpos_wisepad3: Optional[BbposWisepad3]
    bbpos_wisepos_e: Optional[BbposWiseposE]
    cellular: Optional[Cellular]
    deleted: Optional[Literal[True]]
    """
    Always true for a deleted object
    """
    id: str
    """
    Unique identifier for the object.
    """
    is_account_default: Optional[bool]
    """
    Whether this Configuration is the default for your account
    """
    livemode: bool
    """
    If the object exists in live mode, the value is `true`. If the object exists in test mode, the value is `false`.
    """
    name: Optional[str]
    """
    String indicating the name of the Configuration object, set by the user
    """
    object: Literal["terminal.configuration"]
    """
    String representing the object's type. Objects of the same type share the same value.
    """
    offline: Optional[Offline]
    reboot_window: Optional[RebootWindow]
    stripe_s700: Optional[StripeS700]
    stripe_s710: Optional[StripeS710]
    tipping: Optional[Tipping]
    verifone_m425: Optional[VerifoneM425]
    verifone_p400: Optional[VerifoneP400]
    verifone_p630: Optional[VerifoneP630]
    verifone_ux700: Optional[VerifoneUx700]
    verifone_v660p: Optional[VerifoneV660p]
    wifi: Optional[Wifi]

    @classmethod
    def create(
        cls, **params: Unpack["ConfigurationCreateParams"]
    ) -> "Configuration":
        """
        Creates a new Configuration object.
        """
        return cast(
            "Configuration",
            cls._static_request(
                "post",
                cls.class_url(),
                params=params,
            ),
        )

    @classmethod
    async def create_async(
        cls, **params: Unpack["ConfigurationCreateParams"]
    ) -> "Configuration":
        """
        Creates a new Configuration object.
        """
        return cast(
            "Configuration",
            await cls._static_request_async(
                "post",
                cls.class_url(),
                params=params,
            ),
        )

    @classmethod
    def _cls_delete(
        cls, sid: str, **params: Unpack["ConfigurationDeleteParams"]
    ) -> "Configuration":
        """
        Deletes a Configuration object.
        """
        url = "%s/%s" % (cls.class_url(), sanitize_id(sid))
        return cast(
            "Configuration",
            cls._static_request(
                "delete",
                url,
                params=params,
            ),
        )

    @overload
    @staticmethod
    def delete(
        sid: str, **params: Unpack["ConfigurationDeleteParams"]
    ) -> "Configuration":
        """
        Deletes a Configuration object.
        """
        ...

    @overload
    def delete(
        self, **params: Unpack["ConfigurationDeleteParams"]
    ) -> "Configuration":
        """
        Deletes a Configuration object.
        """
        ...

    @class_method_variant("_cls_delete")
    def delete(  # pyright: ignore[reportGeneralTypeIssues]
        self, **params: Unpack["ConfigurationDeleteParams"]
    ) -> "Configuration":
        """
        Deletes a Configuration object.
        """
        return self._request_and_refresh(
            "delete",
            self.instance_url(),
            params=params,
        )

    @classmethod
    async def _cls_delete_async(
        cls, sid: str, **params: Unpack["ConfigurationDeleteParams"]
    ) -> "Configuration":
        """
        Deletes a Configuration object.
        """
        url = "%s/%s" % (cls.class_url(), sanitize_id(sid))
        return cast(
            "Configuration",
            await cls._static_request_async(
                "delete",
                url,
                params=params,
            ),
        )

    @overload
    @staticmethod
    async def delete_async(
        sid: str, **params: Unpack["ConfigurationDeleteParams"]
    ) -> "Configuration":
        """
        Deletes a Configuration object.
        """
        ...

    @overload
    async def delete_async(
        self, **params: Unpack["ConfigurationDeleteParams"]
    ) -> "Configuration":
        """
        Deletes a Configuration object.
        """
        ...

    @class_method_variant("_cls_delete_async")
    async def delete_async(  # pyright: ignore[reportGeneralTypeIssues]
        self, **params: Unpack["ConfigurationDeleteParams"]
    ) -> "Configuration":
        """
        Deletes a Configuration object.
        """
        return await self._request_and_refresh_async(
            "delete",
            self.instance_url(),
            params=params,
        )

    @classmethod
    def list(
        cls, **params: Unpack["ConfigurationListParams"]
    ) -> ListObject["Configuration"]:
        """
        Returns a list of Configuration objects.
        """
        result = cls._static_request(
            "get",
            cls.class_url(),
            params=params,
        )
        if not isinstance(result, ListObject):
            raise TypeError(
                "Expected list object from API, got %s"
                % (type(result).__name__)
            )

        return result

    @classmethod
    async def list_async(
        cls, **params: Unpack["ConfigurationListParams"]
    ) -> ListObject["Configuration"]:
        """
        Returns a list of Configuration objects.
        """
        result = await cls._static_request_async(
            "get",
            cls.class_url(),
            params=params,
        )
        if not isinstance(result, ListObject):
            raise TypeError(
                "Expected list object from API, got %s"
                % (type(result).__name__)
            )

        return result

    @classmethod
    def modify(
        cls, id: str, **params: Unpack["ConfigurationModifyParams"]
    ) -> "Configuration":
        """
        Updates a new Configuration object.
        """
        url = "%s/%s" % (cls.class_url(), sanitize_id(id))
        return cast(
            "Configuration",
            cls._static_request(
                "post",
                url,
                params=params,
            ),
        )

    @classmethod
    async def modify_async(
        cls, id: str, **params: Unpack["ConfigurationModifyParams"]
    ) -> "Configuration":
        """
        Updates a new Configuration object.
        """
        url = "%s/%s" % (cls.class_url(), sanitize_id(id))
        return cast(
            "Configuration",
            await cls._static_request_async(
                "post",
                url,
                params=params,
            ),
        )

    @classmethod
    def retrieve(
        cls, id: str, **params: Unpack["ConfigurationRetrieveParams"]
    ) -> "Configuration":
        """
        Retrieves a Configuration object.
        """
        instance = cls(id, **params)
        instance.refresh()
        return instance

    @classmethod
    async def retrieve_async(
        cls, id: str, **params: Unpack["ConfigurationRetrieveParams"]
    ) -> "Configuration":
        """
        Retrieves a Configuration object.
        """
        instance = cls(id, **params)
        await instance.refresh_async()
        return instance

    _inner_class_types = {
        "bbpos_wisepad3": BbposWisepad3,
        "bbpos_wisepos_e": BbposWiseposE,
        "cellular": Cellular,
        "offline": Offline,
        "reboot_window": RebootWindow,
        "stripe_s700": StripeS700,
        "stripe_s710": StripeS710,
        "tipping": Tipping,
        "verifone_m425": VerifoneM425,
        "verifone_p400": VerifoneP400,
        "verifone_p630": VerifoneP630,
        "verifone_ux700": VerifoneUx700,
        "verifone_v660p": VerifoneV660p,
        "wifi": Wifi,
    }



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._login_link import LoginLink
    from stripe._request_options import RequestOptions
    from stripe.params._account_login_link_create_params import (
        AccountLoginLinkCreateParams,
    )


class AccountLoginLinkService(StripeService):
    def create(
        self,
        account: str,
        params: Optional["AccountLoginLinkCreateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "LoginLink":
        """
        Creates a login link for a connected account to access the Express Dashboard.

        You can only create login links for accounts that use the [Express Dashboard](https://docs.stripe.com/connect/express-dashboard) and are connected to your platform.
        """
        return cast(
            "LoginLink",
            self._request(
                "post",
                "/v1/accounts/{account}/login_links".format(
                    account=sanitize_id(account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        account: str,
        params: Optional["AccountLoginLinkCreateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "LoginLink":
        """
        Creates a login link for a connected account to access the Express Dashboard.

        You can only create login links for accounts that use the [Express Dashboard](https://docs.stripe.com/connect/express-dashboard) and are connected to your platform.
        """
        return cast(
            "LoginLink",
            await self._request_async(
                "post",
                "/v1/accounts/{account}/login_links".format(
                    account=sanitize_id(account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from decimal import Decimal
from stripe._stripe_object import UntypedStripeObject
from typing import Dict, List, Optional, Union
from typing_extensions import Literal, NotRequired, TypedDict


class PersonUpdateParams(TypedDict):
    additional_addresses: NotRequired[
        List["PersonUpdateParamsAdditionalAddress"]
    ]
    """
    Additional addresses associated with the person.
    """
    additional_names: NotRequired[List["PersonUpdateParamsAdditionalName"]]
    """
    Additional names (e.g. aliases) associated with the person.
    """
    additional_terms_of_service: NotRequired[
        "PersonUpdateParamsAdditionalTermsOfService"
    ]
    """
    Attestations of accepted terms of service agreements.
    """
    address: NotRequired["PersonUpdateParamsAddress"]
    """
    The primary address associated with the person.
    """
    date_of_birth: NotRequired["PersonUpdateParamsDateOfBirth"]
    """
    The person's date of birth.
    """
    documents: NotRequired["PersonUpdateParamsDocuments"]
    """
    Documents that may be submitted to satisfy various informational requests.
    """
    email: NotRequired[str]
    """
    Email.
    """
    given_name: NotRequired[str]
    """
    The person's first name.
    """
    id_numbers: NotRequired[List["PersonUpdateParamsIdNumber"]]
    """
    The identification numbers (e.g., SSN) associated with the person.
    """
    legal_gender: NotRequired["Literal['female', 'male']|str"]
    """
    The person's gender (International regulations require either "male" or "female").
    """
    metadata: NotRequired[
        "Dict[str, Optional[str]]|UntypedStripeObject[Optional[str]]"
    ]
    """
    Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
    """
    nationalities: NotRequired[List[str]]
    """
    The nationalities (countries) this person is associated with.
    """
    person_token: NotRequired[str]
    """
    The person token generated by the person token api.
    """
    phone: NotRequired[str]
    """
    The phone number for this person.
    """
    political_exposure: NotRequired["Literal['existing', 'none']|str"]
    """
    The person's political exposure.
    """
    relationship: NotRequired["PersonUpdateParamsRelationship"]
    """
    The relationship that this person has with the Account's business or legal entity.
    """
    script_addresses: NotRequired["PersonUpdateParamsScriptAddresses"]
    """
    The script addresses (e.g., non-Latin characters) associated with the person.
    """
    script_names: NotRequired["PersonUpdateParamsScriptNames"]
    """
    The script names (e.g. non-Latin characters) associated with the person.
    """
    surname: NotRequired[str]
    """
    The person's last name.
    """


class PersonUpdateParamsAdditionalAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    purpose: Literal["registered"]
    """
    Purpose of additional address.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class PersonUpdateParamsAdditionalName(TypedDict):
    full_name: NotRequired[str]
    """
    The person's full name.
    """
    given_name: NotRequired[str]
    """
    The person's first or given name.
    """
    purpose: Literal["alias", "maiden"]
    """
    The purpose or type of the additional name.
    """
    surname: NotRequired[str]
    """
    The person's last or family name.
    """


class PersonUpdateParamsAdditionalTermsOfService(TypedDict):
    account: NotRequired["PersonUpdateParamsAdditionalTermsOfServiceAccount"]
    """
    Stripe terms of service agreement.
    """


class PersonUpdateParamsAdditionalTermsOfServiceAccount(TypedDict):
    date: NotRequired[str]
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: NotRequired[str]
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class PersonUpdateParamsAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class PersonUpdateParamsDateOfBirth(TypedDict):
    day: int
    """
    The day of the birth.
    """
    month: int
    """
    The month of birth.
    """
    year: int
    """
    The year of birth.
    """


class PersonUpdateParamsDocuments(TypedDict):
    company_authorization: NotRequired[
        "PersonUpdateParamsDocumentsCompanyAuthorization"
    ]
    """
    One or more documents that demonstrate proof that this person is authorized to represent the company.
    """
    passport: NotRequired["PersonUpdateParamsDocumentsPassport"]
    """
    One or more documents showing the person's passport page with photo and personal data.
    """
    primary_verification: NotRequired[
        "PersonUpdateParamsDocumentsPrimaryVerification"
    ]
    """
    An identifying document showing the person's name, either a passport or local ID card.
    """
    secondary_verification: NotRequired[
        "PersonUpdateParamsDocumentsSecondaryVerification"
    ]
    """
    A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
    """
    visa: NotRequired["PersonUpdateParamsDocumentsVisa"]
    """
    One or more documents showing the person's visa required for living in the country where they are residing.
    """


class PersonUpdateParamsDocumentsCompanyAuthorization(TypedDict):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class PersonUpdateParamsDocumentsPassport(TypedDict):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class PersonUpdateParamsDocumentsPrimaryVerification(TypedDict):
    front_back: "PersonUpdateParamsDocumentsPrimaryVerificationFrontBack"
    """
    The [file upload](https://docs.stripe.com/api/persons/update#create_file) tokens referring to each side of the document.
    """
    type: Literal["front_back"]
    """
    The format of the verification document. Currently supports `front_back` only.
    """


class PersonUpdateParamsDocumentsPrimaryVerificationFrontBack(TypedDict):
    back: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """
    front: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """


class PersonUpdateParamsDocumentsSecondaryVerification(TypedDict):
    front_back: "PersonUpdateParamsDocumentsSecondaryVerificationFrontBack"
    """
    The [file upload](https://docs.stripe.com/api/persons/update#create_file) tokens referring to each side of the document.
    """
    type: Literal["front_back"]
    """
    The format of the verification document. Currently supports `front_back` only.
    """


class PersonUpdateParamsDocumentsSecondaryVerificationFrontBack(TypedDict):
    back: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """
    front: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """


class PersonUpdateParamsDocumentsVisa(TypedDict):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class PersonUpdateParamsIdNumber(TypedDict):
    type: Union[
        Literal[
            "ae_eid",
            "ao_nif",
            "ar_cuil",
            "ar_dni",
            "at_stn",
            "az_tin",
            "bd_brc",
            "bd_etin",
            "bd_nid",
            "be_nrn",
            "bg_ucn",
            "bn_nric",
            "br_cpf",
            "ca_sin",
            "ch_oasi",
            "cl_rut",
            "cn_pp",
            "co_nuip",
            "cr_ci",
            "cr_cpf",
            "cr_dimex",
            "cr_nite",
            "cy_tic",
            "cz_rc",
            "de_stn",
            "dk_cpr",
            "do_cie",
            "do_rcn",
            "ec_ci",
            "ee_ik",
            "es_nif",
            "fi_hetu",
            "fr_nir",
            "gb_nino",
            "gr_afm",
            "gt_nit",
            "hk_id",
            "hr_oib",
            "hu_ad",
            "id_nik",
            "ie_ppsn",
            "is_kt",
            "it_cf",
            "jp_inc",
            "ke_pin",
            "kz_iin",
            "li_peid",
            "lt_ak",
            "lu_nif",
            "lv_pk",
            "mx_rfc",
            "my_nric",
            "mz_nuit",
            "ng_nin",
            "nl_bsn",
            "no_nin",
            "nz_ird",
            "pe_dni",
            "pk_cnic",
            "pk_snic",
            "pl_pesel",
            "pt_nif",
            "ro_cnp",
            "sa_tin",
            "se_pin",
            "sg_fin",
            "sg_nric",
            "sk_dic",
            "th_lc",
            "th_pin",
            "tr_tin",
            "us_itin",
            "us_itin_last_4",
            "us_ssn",
            "us_ssn_last_4",
            "uy_dni",
            "za_id",
        ],
        str,
    ]
    """
    The ID number type of an individual.
    """
    value: str
    """
    The value of the ID number.
    """


class PersonUpdateParamsRelationship(TypedDict):
    authorizer: NotRequired[bool]
    """
    Whether the individual is an authorizer of the Account's identity.
    """
    director: NotRequired[bool]
    """
    Indicates whether the person is a director of the associated legal entity.
    """
    executive: NotRequired[bool]
    """
    Indicates whether the person is an executive of the associated legal entity.
    """
    legal_guardian: NotRequired[bool]
    """
    Indicates whether the person is a legal guardian of the associated legal entity.
    """
    owner: NotRequired[bool]
    """
    Indicates whether the person is an owner of the associated legal entity.
    """
    percent_ownership: NotRequired[Decimal]
    """
    The percentage of ownership the person has in the associated legal entity.
    """
    representative: NotRequired[bool]
    """
    Indicates whether the person is a representative of the associated legal entity.
    """
    title: NotRequired[str]
    """
    The title or position the person holds in the associated legal entity.
    """


class PersonUpdateParamsScriptAddresses(TypedDict):
    kana: NotRequired["PersonUpdateParamsScriptAddressesKana"]
    """
    Kana Address.
    """
    kanji: NotRequired["PersonUpdateParamsScriptAddressesKanji"]
    """
    Kanji Address.
    """


class PersonUpdateParamsScriptAddressesKana(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class PersonUpdateParamsScriptAddressesKanji(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class PersonUpdateParamsScriptNames(TypedDict):
    kana: NotRequired["PersonUpdateParamsScriptNamesKana"]
    """
    Persons name in kana script.
    """
    kanji: NotRequired["PersonUpdateParamsScriptNamesKanji"]
    """
    Persons name in kanji script.
    """


class PersonUpdateParamsScriptNamesKana(TypedDict):
    given_name: NotRequired[str]
    """
    The person's first or given name.
    """
    surname: NotRequired[str]
    """
    The person's last or family name.
    """


class PersonUpdateParamsScriptNamesKanji(TypedDict):
    given_name: NotRequired[str]
    """
    The person's first or given name.
    """
    surname: NotRequired[str]
    """
    The person's last or family name.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._list_object import ListObject
    from stripe._payment_record import PaymentRecord
    from stripe._request_options import RequestOptions
    from stripe.params._payment_record_list_params import (
        PaymentRecordListParams,
    )
    from stripe.params._payment_record_report_payment_attempt_canceled_params import (
        PaymentRecordReportPaymentAttemptCanceledParams,
    )
    from stripe.params._payment_record_report_payment_attempt_failed_params import (
        PaymentRecordReportPaymentAttemptFailedParams,
    )
    from stripe.params._payment_record_report_payment_attempt_guaranteed_params import (
        PaymentRecordReportPaymentAttemptGuaranteedParams,
    )
    from stripe.params._payment_record_report_payment_attempt_informational_params import (
        PaymentRecordReportPaymentAttemptInformationalParams,
    )
    from stripe.params._payment_record_report_payment_attempt_params import (
        PaymentRecordReportPaymentAttemptParams,
    )
    from stripe.params._payment_record_report_payment_params import (
        PaymentRecordReportPaymentParams,
    )
    from stripe.params._payment_record_report_refund_params import (
        PaymentRecordReportRefundParams,
    )
    from stripe.params._payment_record_retrieve_params import (
        PaymentRecordRetrieveParams,
    )


class PaymentRecordService(StripeService):
    def list(
        self,
        params: Optional["PaymentRecordListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[PaymentRecord]":
        """
        List all the Payment Records for a given merchant.
        """
        return cast(
            "ListObject[PaymentRecord]",
            self._request(
                "get",
                "/v1/payment_records",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["PaymentRecordListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[PaymentRecord]":
        """
        List all the Payment Records for a given merchant.
        """
        return cast(
            "ListObject[PaymentRecord]",
            await self._request_async(
                "get",
                "/v1/payment_records",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        id: str,
        params: Optional["PaymentRecordRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Retrieves a Payment Record with the given ID
        """
        return cast(
            "PaymentRecord",
            self._request(
                "get",
                "/v1/payment_records/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        id: str,
        params: Optional["PaymentRecordRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Retrieves a Payment Record with the given ID
        """
        return cast(
            "PaymentRecord",
            await self._request_async(
                "get",
                "/v1/payment_records/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def report_payment_attempt(
        self,
        id: str,
        params: "PaymentRecordReportPaymentAttemptParams",
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report a new payment attempt on the specified Payment Record. A new payment
         attempt can only be specified if all other payment attempts are canceled or failed.
        """
        return cast(
            "PaymentRecord",
            self._request(
                "post",
                "/v1/payment_records/{id}/report_payment_attempt".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def report_payment_attempt_async(
        self,
        id: str,
        params: "PaymentRecordReportPaymentAttemptParams",
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report a new payment attempt on the specified Payment Record. A new payment
         attempt can only be specified if all other payment attempts are canceled or failed.
        """
        return cast(
            "PaymentRecord",
            await self._request_async(
                "post",
                "/v1/payment_records/{id}/report_payment_attempt".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def report_payment_attempt_canceled(
        self,
        id: str,
        params: "PaymentRecordReportPaymentAttemptCanceledParams",
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report that the most recent payment attempt on the specified Payment Record
         was canceled.
        """
        return cast(
            "PaymentRecord",
            self._request(
                "post",
                "/v1/payment_records/{id}/report_payment_attempt_canceled".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def report_payment_attempt_canceled_async(
        self,
        id: str,
        params: "PaymentRecordReportPaymentAttemptCanceledParams",
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report that the most recent payment attempt on the specified Payment Record
         was canceled.
        """
        return cast(
            "PaymentRecord",
            await self._request_async(
                "post",
                "/v1/payment_records/{id}/report_payment_attempt_canceled".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def report_payment_attempt_failed(
        self,
        id: str,
        params: "PaymentRecordReportPaymentAttemptFailedParams",
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report that the most recent payment attempt on the specified Payment Record
         failed or errored.
        """
        return cast(
            "PaymentRecord",
            self._request(
                "post",
                "/v1/payment_records/{id}/report_payment_attempt_failed".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def report_payment_attempt_failed_async(
        self,
        id: str,
        params: "PaymentRecordReportPaymentAttemptFailedParams",
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report that the most recent payment attempt on the specified Payment Record
         failed or errored.
        """
        return cast(
            "PaymentRecord",
            await self._request_async(
                "post",
                "/v1/payment_records/{id}/report_payment_attempt_failed".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def report_payment_attempt_guaranteed(
        self,
        id: str,
        params: "PaymentRecordReportPaymentAttemptGuaranteedParams",
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report that the most recent payment attempt on the specified Payment Record
         was guaranteed.
        """
        return cast(
            "PaymentRecord",
            self._request(
                "post",
                "/v1/payment_records/{id}/report_payment_attempt_guaranteed".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def report_payment_attempt_guaranteed_async(
        self,
        id: str,
        params: "PaymentRecordReportPaymentAttemptGuaranteedParams",
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report that the most recent payment attempt on the specified Payment Record
         was guaranteed.
        """
        return cast(
            "PaymentRecord",
            await self._request_async(
                "post",
                "/v1/payment_records/{id}/report_payment_attempt_guaranteed".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def report_payment_attempt_informational(
        self,
        id: str,
        params: Optional[
            "PaymentRecordReportPaymentAttemptInformationalParams"
        ] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report informational updates on the specified Payment Record.
        """
        return cast(
            "PaymentRecord",
            self._request(
                "post",
                "/v1/payment_records/{id}/report_payment_attempt_informational".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def report_payment_attempt_informational_async(
        self,
        id: str,
        params: Optional[
            "PaymentRecordReportPaymentAttemptInformationalParams"
        ] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report informational updates on the specified Payment Record.
        """
        return cast(
            "PaymentRecord",
            await self._request_async(
                "post",
                "/v1/payment_records/{id}/report_payment_attempt_informational".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def report_refund(
        self,
        id: str,
        params: "PaymentRecordReportRefundParams",
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report that the most recent payment attempt on the specified Payment Record
         was refunded.
        """
        return cast(
            "PaymentRecord",
            self._request(
                "post",
                "/v1/payment_records/{id}/report_refund".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def report_refund_async(
        self,
        id: str,
        params: "PaymentRecordReportRefundParams",
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report that the most recent payment attempt on the specified Payment Record
         was refunded.
        """
        return cast(
            "PaymentRecord",
            await self._request_async(
                "post",
                "/v1/payment_records/{id}/report_refund".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def report_payment(
        self,
        params: "PaymentRecordReportPaymentParams",
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report a new Payment Record. You may report a Payment Record as it is
         initialized and later report updates through the other report_* methods, or report Payment
         Records in a terminal state directly, through this method.
        """
        return cast(
            "PaymentRecord",
            self._request(
                "post",
                "/v1/payment_records/report_payment",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def report_payment_async(
        self,
        params: "PaymentRecordReportPaymentParams",
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentRecord":
        """
        Report a new Payment Record. You may report a Payment Record as it is
         initialized and later report updates through the other report_* methods, or report Payment
         Records in a terminal state directly, through this method.
        """
        return cast(
            "PaymentRecord",
            await self._request_async(
                "post",
                "/v1/payment_records/report_payment",
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._request_options import RequestOptions
    from stripe.params.test_helpers.treasury._outbound_payment_fail_params import (
        OutboundPaymentFailParams,
    )
    from stripe.params.test_helpers.treasury._outbound_payment_post_params import (
        OutboundPaymentPostParams,
    )
    from stripe.params.test_helpers.treasury._outbound_payment_return_outbound_payment_params import (
        OutboundPaymentReturnOutboundPaymentParams,
    )
    from stripe.params.test_helpers.treasury._outbound_payment_update_params import (
        OutboundPaymentUpdateParams,
    )
    from stripe.treasury._outbound_payment import OutboundPayment


class OutboundPaymentService(StripeService):
    def update(
        self,
        id: str,
        params: "OutboundPaymentUpdateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "OutboundPayment":
        """
        Updates a test mode created OutboundPayment with tracking details. The OutboundPayment must not be cancelable, and cannot be in the canceled or failed states.
        """
        return cast(
            "OutboundPayment",
            self._request(
                "post",
                "/v1/test_helpers/treasury/outbound_payments/{id}".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def update_async(
        self,
        id: str,
        params: "OutboundPaymentUpdateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "OutboundPayment":
        """
        Updates a test mode created OutboundPayment with tracking details. The OutboundPayment must not be cancelable, and cannot be in the canceled or failed states.
        """
        return cast(
            "OutboundPayment",
            await self._request_async(
                "post",
                "/v1/test_helpers/treasury/outbound_payments/{id}".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def fail(
        self,
        id: str,
        params: Optional["OutboundPaymentFailParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "OutboundPayment":
        """
        Transitions a test mode created OutboundPayment to the failed status. The OutboundPayment must already be in the processing state.
        """
        return cast(
            "OutboundPayment",
            self._request(
                "post",
                "/v1/test_helpers/treasury/outbound_payments/{id}/fail".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def fail_async(
        self,
        id: str,
        params: Optional["OutboundPaymentFailParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "OutboundPayment":
        """
        Transitions a test mode created OutboundPayment to the failed status. The OutboundPayment must already be in the processing state.
        """
        return cast(
            "OutboundPayment",
            await self._request_async(
                "post",
                "/v1/test_helpers/treasury/outbound_payments/{id}/fail".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def post(
        self,
        id: str,
        params: Optional["OutboundPaymentPostParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "OutboundPayment":
        """
        Transitions a test mode created OutboundPayment to the posted status. The OutboundPayment must already be in the processing state.
        """
        return cast(
            "OutboundPayment",
            self._request(
                "post",
                "/v1/test_helpers/treasury/outbound_payments/{id}/post".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def post_async(
        self,
        id: str,
        params: Optional["OutboundPaymentPostParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "OutboundPayment":
        """
        Transitions a test mode created OutboundPayment to the posted status. The OutboundPayment must already be in the processing state.
        """
        return cast(
            "OutboundPayment",
            await self._request_async(
                "post",
                "/v1/test_helpers/treasury/outbound_payments/{id}/post".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def return_outbound_payment(
        self,
        id: str,
        params: Optional["OutboundPaymentReturnOutboundPaymentParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "OutboundPayment":
        """
        Transitions a test mode created OutboundPayment to the returned status. The OutboundPayment must already be in the processing state.
        """
        return cast(
            "OutboundPayment",
            self._request(
                "post",
                "/v1/test_helpers/treasury/outbound_payments/{id}/return".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def return_outbound_payment_async(
        self,
        id: str,
        params: Optional["OutboundPaymentReturnOutboundPaymentParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "OutboundPayment":
        """
        Transitions a test mode created OutboundPayment to the returned status. The OutboundPayment must already be in the processing state.
        """
        return cast(
            "OutboundPayment",
            await self._request_async(
                "post",
                "/v1/test_helpers/treasury/outbound_payments/{id}/return".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing import List, Union
from typing_extensions import Literal, NotRequired, TypedDict


class TokenUpdateParams(TypedDict):
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    status: Union[Literal["active", "deleted", "suspended"], str]
    """
    Specifies which status the token should be updated to.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._list_object import ListObject
    from stripe._request_options import RequestOptions
    from stripe.params.terminal._reader_cancel_action_params import (
        ReaderCancelActionParams,
    )
    from stripe.params.terminal._reader_collect_inputs_params import (
        ReaderCollectInputsParams,
    )
    from stripe.params.terminal._reader_collect_payment_method_params import (
        ReaderCollectPaymentMethodParams,
    )
    from stripe.params.terminal._reader_confirm_payment_intent_params import (
        ReaderConfirmPaymentIntentParams,
    )
    from stripe.params.terminal._reader_create_params import ReaderCreateParams
    from stripe.params.terminal._reader_delete_params import ReaderDeleteParams
    from stripe.params.terminal._reader_list_params import ReaderListParams
    from stripe.params.terminal._reader_process_payment_intent_params import (
        ReaderProcessPaymentIntentParams,
    )
    from stripe.params.terminal._reader_process_setup_intent_params import (
        ReaderProcessSetupIntentParams,
    )
    from stripe.params.terminal._reader_refund_payment_params import (
        ReaderRefundPaymentParams,
    )
    from stripe.params.terminal._reader_retrieve_params import (
        ReaderRetrieveParams,
    )
    from stripe.params.terminal._reader_set_reader_display_params import (
        ReaderSetReaderDisplayParams,
    )
    from stripe.params.terminal._reader_update_params import ReaderUpdateParams
    from stripe.terminal._reader import Reader


class ReaderService(StripeService):
    def delete(
        self,
        reader: str,
        params: Optional["ReaderDeleteParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Deletes a Reader object.
        """
        return cast(
            "Reader",
            self._request(
                "delete",
                "/v1/terminal/readers/{reader}".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def delete_async(
        self,
        reader: str,
        params: Optional["ReaderDeleteParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Deletes a Reader object.
        """
        return cast(
            "Reader",
            await self._request_async(
                "delete",
                "/v1/terminal/readers/{reader}".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        reader: str,
        params: Optional["ReaderRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Retrieves a Reader object.
        """
        return cast(
            "Reader",
            self._request(
                "get",
                "/v1/terminal/readers/{reader}".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        reader: str,
        params: Optional["ReaderRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Retrieves a Reader object.
        """
        return cast(
            "Reader",
            await self._request_async(
                "get",
                "/v1/terminal/readers/{reader}".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def update(
        self,
        reader: str,
        params: Optional["ReaderUpdateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Updates a Reader object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
        """
        return cast(
            "Reader",
            self._request(
                "post",
                "/v1/terminal/readers/{reader}".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def update_async(
        self,
        reader: str,
        params: Optional["ReaderUpdateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Updates a Reader object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
        """
        return cast(
            "Reader",
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def list(
        self,
        params: Optional["ReaderListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[Reader]":
        """
        Returns a list of Reader objects.
        """
        return cast(
            "ListObject[Reader]",
            self._request(
                "get",
                "/v1/terminal/readers",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["ReaderListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[Reader]":
        """
        Returns a list of Reader objects.
        """
        return cast(
            "ListObject[Reader]",
            await self._request_async(
                "get",
                "/v1/terminal/readers",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def create(
        self,
        params: "ReaderCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Creates a new Reader object.
        """
        return cast(
            "Reader",
            self._request(
                "post",
                "/v1/terminal/readers",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: "ReaderCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Creates a new Reader object.
        """
        return cast(
            "Reader",
            await self._request_async(
                "post",
                "/v1/terminal/readers",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def cancel_action(
        self,
        reader: str,
        params: Optional["ReaderCancelActionParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Cancels the current reader action. See [Programmatic Cancellation](https://docs.stripe.com/docs/terminal/payments/collect-card-payment?terminal-sdk-platform=server-driven#programmatic-cancellation) for more details.
        """
        return cast(
            "Reader",
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/cancel_action".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def cancel_action_async(
        self,
        reader: str,
        params: Optional["ReaderCancelActionParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Cancels the current reader action. See [Programmatic Cancellation](https://docs.stripe.com/docs/terminal/payments/collect-card-payment?terminal-sdk-platform=server-driven#programmatic-cancellation) for more details.
        """
        return cast(
            "Reader",
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/cancel_action".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def collect_inputs(
        self,
        reader: str,
        params: "ReaderCollectInputsParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Initiates an [input collection flow](https://docs.stripe.com/docs/terminal/features/collect-inputs) on a Reader to display input forms and collect information from your customers.
        """
        return cast(
            "Reader",
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/collect_inputs".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def collect_inputs_async(
        self,
        reader: str,
        params: "ReaderCollectInputsParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Initiates an [input collection flow](https://docs.stripe.com/docs/terminal/features/collect-inputs) on a Reader to display input forms and collect information from your customers.
        """
        return cast(
            "Reader",
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/collect_inputs".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def collect_payment_method(
        self,
        reader: str,
        params: "ReaderCollectPaymentMethodParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Initiates a payment flow on a Reader and updates the PaymentIntent with card details before manual confirmation. See [Collecting a Payment method](https://docs.stripe.com/docs/terminal/payments/collect-card-payment?terminal-sdk-platform=server-driven&process=inspect#collect-a-paymentmethod) for more details.
        """
        return cast(
            "Reader",
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/collect_payment_method".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def collect_payment_method_async(
        self,
        reader: str,
        params: "ReaderCollectPaymentMethodParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Initiates a payment flow on a Reader and updates the PaymentIntent with card details before manual confirmation. See [Collecting a Payment method](https://docs.stripe.com/docs/terminal/payments/collect-card-payment?terminal-sdk-platform=server-driven&process=inspect#collect-a-paymentmethod) for more details.
        """
        return cast(
            "Reader",
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/collect_payment_method".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def confirm_payment_intent(
        self,
        reader: str,
        params: "ReaderConfirmPaymentIntentParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Finalizes a payment on a Reader. See [Confirming a Payment](https://docs.stripe.com/docs/terminal/payments/collect-card-payment?terminal-sdk-platform=server-driven&process=inspect#confirm-the-paymentintent) for more details.
        """
        return cast(
            "Reader",
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/confirm_payment_intent".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def confirm_payment_intent_async(
        self,
        reader: str,
        params: "ReaderConfirmPaymentIntentParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Finalizes a payment on a Reader. See [Confirming a Payment](https://docs.stripe.com/docs/terminal/payments/collect-card-payment?terminal-sdk-platform=server-driven&process=inspect#confirm-the-paymentintent) for more details.
        """
        return cast(
            "Reader",
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/confirm_payment_intent".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def process_payment_intent(
        self,
        reader: str,
        params: "ReaderProcessPaymentIntentParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Initiates a payment flow on a Reader. See [process the payment](https://docs.stripe.com/docs/terminal/payments/collect-card-payment?terminal-sdk-platform=server-driven&process=immediately#process-payment) for more details.
        """
        return cast(
            "Reader",
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/process_payment_intent".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def process_payment_intent_async(
        self,
        reader: str,
        params: "ReaderProcessPaymentIntentParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Initiates a payment flow on a Reader. See [process the payment](https://docs.stripe.com/docs/terminal/payments/collect-card-payment?terminal-sdk-platform=server-driven&process=immediately#process-payment) for more details.
        """
        return cast(
            "Reader",
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/process_payment_intent".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def process_setup_intent(
        self,
        reader: str,
        params: "ReaderProcessSetupIntentParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Initiates a SetupIntent flow on a Reader. See [Save directly without charging](https://docs.stripe.com/docs/terminal/features/saving-payment-details/save-directly) for more details.
        """
        return cast(
            "Reader",
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/process_setup_intent".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def process_setup_intent_async(
        self,
        reader: str,
        params: "ReaderProcessSetupIntentParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Initiates a SetupIntent flow on a Reader. See [Save directly without charging](https://docs.stripe.com/docs/terminal/features/saving-payment-details/save-directly) for more details.
        """
        return cast(
            "Reader",
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/process_setup_intent".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def refund_payment(
        self,
        reader: str,
        params: Optional["ReaderRefundPaymentParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Initiates an in-person refund on a Reader. See [Refund an Interac Payment](https://docs.stripe.com/docs/terminal/payments/regional?integration-country=CA#refund-an-interac-payment) for more details.
        """
        return cast(
            "Reader",
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/refund_payment".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def refund_payment_async(
        self,
        reader: str,
        params: Optional["ReaderRefundPaymentParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Initiates an in-person refund on a Reader. See [Refund an Interac Payment](https://docs.stripe.com/docs/terminal/payments/regional?integration-country=CA#refund-an-interac-payment) for more details.
        """
        return cast(
            "Reader",
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/refund_payment".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def set_reader_display(
        self,
        reader: str,
        params: "ReaderSetReaderDisplayParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Sets the reader display to show [cart details](https://docs.stripe.com/docs/terminal/features/display).
        """
        return cast(
            "Reader",
            self._request(
                "post",
                "/v1/terminal/readers/{reader}/set_reader_display".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def set_reader_display_async(
        self,
        reader: str,
        params: "ReaderSetReaderDisplayParams",
        options: Optional["RequestOptions"] = None,
    ) -> "Reader":
        """
        Sets the reader display to show [cart details](https://docs.stripe.com/docs/terminal/features/display).
        """
        return cast(
            "Reader",
            await self._request_async(
                "post",
                "/v1/terminal/readers/{reader}/set_reader_display".format(
                    reader=sanitize_id(reader),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.checkout._session_create_params import (
        SessionCreateParams as SessionCreateParams,
        SessionCreateParamsAdaptivePricing as SessionCreateParamsAdaptivePricing,
        SessionCreateParamsAfterExpiration as SessionCreateParamsAfterExpiration,
        SessionCreateParamsAfterExpirationRecovery as SessionCreateParamsAfterExpirationRecovery,
        SessionCreateParamsAutomaticTax as SessionCreateParamsAutomaticTax,
        SessionCreateParamsAutomaticTaxLiability as SessionCreateParamsAutomaticTaxLiability,
        SessionCreateParamsBrandingSettings as SessionCreateParamsBrandingSettings,
        SessionCreateParamsBrandingSettingsIcon as SessionCreateParamsBrandingSettingsIcon,
        SessionCreateParamsBrandingSettingsLogo as SessionCreateParamsBrandingSettingsLogo,
        SessionCreateParamsConsentCollection as SessionCreateParamsConsentCollection,
        SessionCreateParamsConsentCollectionPaymentMethodReuseAgreement as SessionCreateParamsConsentCollectionPaymentMethodReuseAgreement,
        SessionCreateParamsCustomField as SessionCreateParamsCustomField,
        SessionCreateParamsCustomFieldDropdown as SessionCreateParamsCustomFieldDropdown,
        SessionCreateParamsCustomFieldDropdownOption as SessionCreateParamsCustomFieldDropdownOption,
        SessionCreateParamsCustomFieldLabel as SessionCreateParamsCustomFieldLabel,
        SessionCreateParamsCustomFieldNumeric as SessionCreateParamsCustomFieldNumeric,
        SessionCreateParamsCustomFieldText as SessionCreateParamsCustomFieldText,
        SessionCreateParamsCustomText as SessionCreateParamsCustomText,
        SessionCreateParamsCustomTextAfterSubmit as SessionCreateParamsCustomTextAfterSubmit,
        SessionCreateParamsCustomTextShippingAddress as SessionCreateParamsCustomTextShippingAddress,
        SessionCreateParamsCustomTextSubmit as SessionCreateParamsCustomTextSubmit,
        SessionCreateParamsCustomTextTermsOfServiceAcceptance as SessionCreateParamsCustomTextTermsOfServiceAcceptance,
        SessionCreateParamsCustomerUpdate as SessionCreateParamsCustomerUpdate,
        SessionCreateParamsDiscount as SessionCreateParamsDiscount,
        SessionCreateParamsInvoiceCreation as SessionCreateParamsInvoiceCreation,
        SessionCreateParamsInvoiceCreationInvoiceData as SessionCreateParamsInvoiceCreationInvoiceData,
        SessionCreateParamsInvoiceCreationInvoiceDataCustomField as SessionCreateParamsInvoiceCreationInvoiceDataCustomField,
        SessionCreateParamsInvoiceCreationInvoiceDataIssuer as SessionCreateParamsInvoiceCreationInvoiceDataIssuer,
        SessionCreateParamsInvoiceCreationInvoiceDataRenderingOptions as SessionCreateParamsInvoiceCreationInvoiceDataRenderingOptions,
        SessionCreateParamsLineItem as SessionCreateParamsLineItem,
        SessionCreateParamsLineItemAdjustableQuantity as SessionCreateParamsLineItemAdjustableQuantity,
        SessionCreateParamsLineItemPriceData as SessionCreateParamsLineItemPriceData,
        SessionCreateParamsLineItemPriceDataProductData as SessionCreateParamsLineItemPriceDataProductData,
        SessionCreateParamsLineItemPriceDataRecurring as SessionCreateParamsLineItemPriceDataRecurring,
        SessionCreateParamsManagedPayments as SessionCreateParamsManagedPayments,
        SessionCreateParamsNameCollection as SessionCreateParamsNameCollection,
        SessionCreateParamsNameCollectionBusiness as SessionCreateParamsNameCollectionBusiness,
        SessionCreateParamsNameCollectionIndividual as SessionCreateParamsNameCollectionIndividual,
        SessionCreateParamsOptionalItem as SessionCreateParamsOptionalItem,
        SessionCreateParamsOptionalItemAdjustableQuantity as SessionCreateParamsOptionalItemAdjustableQuantity,
        SessionCreateParamsPaymentIntentData as SessionCreateParamsPaymentIntentData,
        SessionCreateParamsPaymentIntentDataShipping as SessionCreateParamsPaymentIntentDataShipping,
        SessionCreateParamsPaymentIntentDataShippingAddress as SessionCreateParamsPaymentIntentDataShippingAddress,
        SessionCreateParamsPaymentIntentDataTransferData as SessionCreateParamsPaymentIntentDataTransferData,
        SessionCreateParamsPaymentMethodData as SessionCreateParamsPaymentMethodData,
        SessionCreateParamsPaymentMethodOptions as SessionCreateParamsPaymentMethodOptions,
        SessionCreateParamsPaymentMethodOptionsAcssDebit as SessionCreateParamsPaymentMethodOptionsAcssDebit,
        SessionCreateParamsPaymentMethodOptionsAcssDebitMandateOptions as SessionCreateParamsPaymentMethodOptionsAcssDebitMandateOptions,
        SessionCreateParamsPaymentMethodOptionsAffirm as SessionCreateParamsPaymentMethodOptionsAffirm,
        SessionCreateParamsPaymentMethodOptionsAfterpayClearpay as SessionCreateParamsPaymentMethodOptionsAfterpayClearpay,
        SessionCreateParamsPaymentMethodOptionsAlipay as SessionCreateParamsPaymentMethodOptionsAlipay,
        SessionCreateParamsPaymentMethodOptionsAlma as SessionCreateParamsPaymentMethodOptionsAlma,
        SessionCreateParamsPaymentMethodOptionsAmazonPay as SessionCreateParamsPaymentMethodOptionsAmazonPay,
        SessionCreateParamsPaymentMethodOptionsAuBecsDebit as SessionCreateParamsPaymentMethodOptionsAuBecsDebit,
        SessionCreateParamsPaymentMethodOptionsBacsDebit as SessionCreateParamsPaymentMethodOptionsBacsDebit,
        SessionCreateParamsPaymentMethodOptionsBacsDebitMandateOptions as SessionCreateParamsPaymentMethodOptionsBacsDebitMandateOptions,
        SessionCreateParamsPaymentMethodOptionsBancontact as SessionCreateParamsPaymentMethodOptionsBancontact,
        SessionCreateParamsPaymentMethodOptionsBillie as SessionCreateParamsPaymentMethodOptionsBillie,
        SessionCreateParamsPaymentMethodOptionsBoleto as SessionCreateParamsPaymentMethodOptionsBoleto,
        SessionCreateParamsPaymentMethodOptionsCard as SessionCreateParamsPaymentMethodOptionsCard,
        SessionCreateParamsPaymentMethodOptionsCardInstallments as SessionCreateParamsPaymentMethodOptionsCardInstallments,
        SessionCreateParamsPaymentMethodOptionsCardRestrictions as SessionCreateParamsPaymentMethodOptionsCardRestrictions,
        SessionCreateParamsPaymentMethodOptionsCashapp as SessionCreateParamsPaymentMethodOptionsCashapp,
        SessionCreateParamsPaymentMethodOptionsCrypto as SessionCreateParamsPaymentMethodOptionsCrypto,
        SessionCreateParamsPaymentMethodOptionsCustomerBalance as SessionCreateParamsPaymentMethodOptionsCustomerBalance,
        SessionCreateParamsPaymentMethodOptionsCustomerBalanceBankTransfer as SessionCreateParamsPaymentMethodOptionsCustomerBalanceBankTransfer,
        SessionCreateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as SessionCreateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        SessionCreateParamsPaymentMethodOptionsDemoPay as SessionCreateParamsPaymentMethodOptionsDemoPay,
        SessionCreateParamsPaymentMethodOptionsEps as SessionCreateParamsPaymentMethodOptionsEps,
        SessionCreateParamsPaymentMethodOptionsFpx as SessionCreateParamsPaymentMethodOptionsFpx,
        SessionCreateParamsPaymentMethodOptionsGiropay as SessionCreateParamsPaymentMethodOptionsGiropay,
        SessionCreateParamsPaymentMethodOptionsGrabpay as SessionCreateParamsPaymentMethodOptionsGrabpay,
        SessionCreateParamsPaymentMethodOptionsIdeal as SessionCreateParamsPaymentMethodOptionsIdeal,
        SessionCreateParamsPaymentMethodOptionsKakaoPay as SessionCreateParamsPaymentMethodOptionsKakaoPay,
        SessionCreateParamsPaymentMethodOptionsKlarna as SessionCreateParamsPaymentMethodOptionsKlarna,
        SessionCreateParamsPaymentMethodOptionsKlarnaSubscription as SessionCreateParamsPaymentMethodOptionsKlarnaSubscription,
        SessionCreateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling as SessionCreateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling,
        SessionCreateParamsPaymentMethodOptionsKonbini as SessionCreateParamsPaymentMethodOptionsKonbini,
        SessionCreateParamsPaymentMethodOptionsKrCard as SessionCreateParamsPaymentMethodOptionsKrCard,
        SessionCreateParamsPaymentMethodOptionsLink as SessionCreateParamsPaymentMethodOptionsLink,
        SessionCreateParamsPaymentMethodOptionsMobilepay as SessionCreateParamsPaymentMethodOptionsMobilepay,
        SessionCreateParamsPaymentMethodOptionsMultibanco as SessionCreateParamsPaymentMethodOptionsMultibanco,
        SessionCreateParamsPaymentMethodOptionsNaverPay as SessionCreateParamsPaymentMethodOptionsNaverPay,
        SessionCreateParamsPaymentMethodOptionsOxxo as SessionCreateParamsPaymentMethodOptionsOxxo,
        SessionCreateParamsPaymentMethodOptionsP24 as SessionCreateParamsPaymentMethodOptionsP24,
        SessionCreateParamsPaymentMethodOptionsPayByBank as SessionCreateParamsPaymentMethodOptionsPayByBank,
        SessionCreateParamsPaymentMethodOptionsPayco as SessionCreateParamsPaymentMethodOptionsPayco,
        SessionCreateParamsPaymentMethodOptionsPaynow as SessionCreateParamsPaymentMethodOptionsPaynow,
        SessionCreateParamsPaymentMethodOptionsPaypal as SessionCreateParamsPaymentMethodOptionsPaypal,
        SessionCreateParamsPaymentMethodOptionsPayto as SessionCreateParamsPaymentMethodOptionsPayto,
        SessionCreateParamsPaymentMethodOptionsPaytoMandateOptions as SessionCreateParamsPaymentMethodOptionsPaytoMandateOptions,
        SessionCreateParamsPaymentMethodOptionsPix as SessionCreateParamsPaymentMethodOptionsPix,
        SessionCreateParamsPaymentMethodOptionsPixMandateOptions as SessionCreateParamsPaymentMethodOptionsPixMandateOptions,
        SessionCreateParamsPaymentMethodOptionsRevolutPay as SessionCreateParamsPaymentMethodOptionsRevolutPay,
        SessionCreateParamsPaymentMethodOptionsSamsungPay as SessionCreateParamsPaymentMethodOptionsSamsungPay,
        SessionCreateParamsPaymentMethodOptionsSatispay as SessionCreateParamsPaymentMethodOptionsSatispay,
        SessionCreateParamsPaymentMethodOptionsScalapay as SessionCreateParamsPaymentMethodOptionsScalapay,
        SessionCreateParamsPaymentMethodOptionsSepaDebit as SessionCreateParamsPaymentMethodOptionsSepaDebit,
        SessionCreateParamsPaymentMethodOptionsSepaDebitMandateOptions as SessionCreateParamsPaymentMethodOptionsSepaDebitMandateOptions,
        SessionCreateParamsPaymentMethodOptionsSofort as SessionCreateParamsPaymentMethodOptionsSofort,
        SessionCreateParamsPaymentMethodOptionsSunbit as SessionCreateParamsPaymentMethodOptionsSunbit,
        SessionCreateParamsPaymentMethodOptionsSwish as SessionCreateParamsPaymentMethodOptionsSwish,
        SessionCreateParamsPaymentMethodOptionsTwint as SessionCreateParamsPaymentMethodOptionsTwint,
        SessionCreateParamsPaymentMethodOptionsUpi as SessionCreateParamsPaymentMethodOptionsUpi,
        SessionCreateParamsPaymentMethodOptionsUpiMandateOptions as SessionCreateParamsPaymentMethodOptionsUpiMandateOptions,
        SessionCreateParamsPaymentMethodOptionsUsBankAccount as SessionCreateParamsPaymentMethodOptionsUsBankAccount,
        SessionCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections as SessionCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections,
        SessionCreateParamsPaymentMethodOptionsWechatPay as SessionCreateParamsPaymentMethodOptionsWechatPay,
        SessionCreateParamsPermissions as SessionCreateParamsPermissions,
        SessionCreateParamsPhoneNumberCollection as SessionCreateParamsPhoneNumberCollection,
        SessionCreateParamsSavedPaymentMethodOptions as SessionCreateParamsSavedPaymentMethodOptions,
        SessionCreateParamsSetupIntentData as SessionCreateParamsSetupIntentData,
        SessionCreateParamsShippingAddressCollection as SessionCreateParamsShippingAddressCollection,
        SessionCreateParamsShippingOption as SessionCreateParamsShippingOption,
        SessionCreateParamsShippingOptionShippingRateData as SessionCreateParamsShippingOptionShippingRateData,
        SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimate as SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimate,
        SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimateMaximum as SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimateMaximum,
        SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimateMinimum as SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimateMinimum,
        SessionCreateParamsShippingOptionShippingRateDataFixedAmount as SessionCreateParamsShippingOptionShippingRateDataFixedAmount,
        SessionCreateParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions as SessionCreateParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions,
        SessionCreateParamsSubscriptionData as SessionCreateParamsSubscriptionData,
        SessionCreateParamsSubscriptionDataBillingCycleAnchorConfig as SessionCreateParamsSubscriptionDataBillingCycleAnchorConfig,
        SessionCreateParamsSubscriptionDataBillingMode as SessionCreateParamsSubscriptionDataBillingMode,
        SessionCreateParamsSubscriptionDataBillingModeFlexible as SessionCreateParamsSubscriptionDataBillingModeFlexible,
        SessionCreateParamsSubscriptionDataInvoiceSettings as SessionCreateParamsSubscriptionDataInvoiceSettings,
        SessionCreateParamsSubscriptionDataInvoiceSettingsIssuer as SessionCreateParamsSubscriptionDataInvoiceSettingsIssuer,
        SessionCreateParamsSubscriptionDataPendingInvoiceItemInterval as SessionCreateParamsSubscriptionDataPendingInvoiceItemInterval,
        SessionCreateParamsSubscriptionDataTransferData as SessionCreateParamsSubscriptionDataTransferData,
        SessionCreateParamsSubscriptionDataTrialSettings as SessionCreateParamsSubscriptionDataTrialSettings,
        SessionCreateParamsSubscriptionDataTrialSettingsEndBehavior as SessionCreateParamsSubscriptionDataTrialSettingsEndBehavior,
        SessionCreateParamsTaxIdCollection as SessionCreateParamsTaxIdCollection,
        SessionCreateParamsWalletOptions as SessionCreateParamsWalletOptions,
        SessionCreateParamsWalletOptionsLink as SessionCreateParamsWalletOptionsLink,
    )
    from stripe.params.checkout._session_expire_params import (
        SessionExpireParams as SessionExpireParams,
    )
    from stripe.params.checkout._session_line_item_list_params import (
        SessionLineItemListParams as SessionLineItemListParams,
    )
    from stripe.params.checkout._session_list_line_items_params import (
        SessionListLineItemsParams as SessionListLineItemsParams,
    )
    from stripe.params.checkout._session_list_params import (
        SessionListParams as SessionListParams,
        SessionListParamsCreated as SessionListParamsCreated,
        SessionListParamsCustomerDetails as SessionListParamsCustomerDetails,
    )
    from stripe.params.checkout._session_modify_params import (
        SessionModifyParams as SessionModifyParams,
        SessionModifyParamsCollectedInformation as SessionModifyParamsCollectedInformation,
        SessionModifyParamsCollectedInformationShippingDetails as SessionModifyParamsCollectedInformationShippingDetails,
        SessionModifyParamsCollectedInformationShippingDetailsAddress as SessionModifyParamsCollectedInformationShippingDetailsAddress,
        SessionModifyParamsLineItem as SessionModifyParamsLineItem,
        SessionModifyParamsLineItemAdjustableQuantity as SessionModifyParamsLineItemAdjustableQuantity,
        SessionModifyParamsLineItemPriceData as SessionModifyParamsLineItemPriceData,
        SessionModifyParamsLineItemPriceDataProductData as SessionModifyParamsLineItemPriceDataProductData,
        SessionModifyParamsLineItemPriceDataRecurring as SessionModifyParamsLineItemPriceDataRecurring,
        SessionModifyParamsShippingOption as SessionModifyParamsShippingOption,
        SessionModifyParamsShippingOptionShippingRateData as SessionModifyParamsShippingOptionShippingRateData,
        SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimate as SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimate,
        SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimateMaximum as SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimateMaximum,
        SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimateMinimum as SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimateMinimum,
        SessionModifyParamsShippingOptionShippingRateDataFixedAmount as SessionModifyParamsShippingOptionShippingRateDataFixedAmount,
        SessionModifyParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions as SessionModifyParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions,
    )
    from stripe.params.checkout._session_retrieve_params import (
        SessionRetrieveParams as SessionRetrieveParams,
    )
    from stripe.params.checkout._session_update_params import (
        SessionUpdateParams as SessionUpdateParams,
        SessionUpdateParamsCollectedInformation as SessionUpdateParamsCollectedInformation,
        SessionUpdateParamsCollectedInformationShippingDetails as SessionUpdateParamsCollectedInformationShippingDetails,
        SessionUpdateParamsCollectedInformationShippingDetailsAddress as SessionUpdateParamsCollectedInformationShippingDetailsAddress,
        SessionUpdateParamsLineItem as SessionUpdateParamsLineItem,
        SessionUpdateParamsLineItemAdjustableQuantity as SessionUpdateParamsLineItemAdjustableQuantity,
        SessionUpdateParamsLineItemPriceData as SessionUpdateParamsLineItemPriceData,
        SessionUpdateParamsLineItemPriceDataProductData as SessionUpdateParamsLineItemPriceDataProductData,
        SessionUpdateParamsLineItemPriceDataRecurring as SessionUpdateParamsLineItemPriceDataRecurring,
        SessionUpdateParamsShippingOption as SessionUpdateParamsShippingOption,
        SessionUpdateParamsShippingOptionShippingRateData as SessionUpdateParamsShippingOptionShippingRateData,
        SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimate as SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimate,
        SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimateMaximum as SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimateMaximum,
        SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimateMinimum as SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimateMinimum,
        SessionUpdateParamsShippingOptionShippingRateDataFixedAmount as SessionUpdateParamsShippingOptionShippingRateDataFixedAmount,
        SessionUpdateParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions as SessionUpdateParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "SessionCreateParams": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsAdaptivePricing": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsAfterExpiration": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsAfterExpirationRecovery": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsAutomaticTax": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsAutomaticTaxLiability": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsBrandingSettings": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsBrandingSettingsIcon": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsBrandingSettingsLogo": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsConsentCollection": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsConsentCollectionPaymentMethodReuseAgreement": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomField": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomFieldDropdown": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomFieldDropdownOption": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomFieldLabel": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomFieldNumeric": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomFieldText": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomText": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomTextAfterSubmit": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomTextShippingAddress": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomTextSubmit": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomTextTermsOfServiceAcceptance": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomerUpdate": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsDiscount": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsInvoiceCreation": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsInvoiceCreationInvoiceData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsInvoiceCreationInvoiceDataCustomField": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsInvoiceCreationInvoiceDataIssuer": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsInvoiceCreationInvoiceDataRenderingOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsLineItem": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsLineItemAdjustableQuantity": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsLineItemPriceData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsLineItemPriceDataProductData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsLineItemPriceDataRecurring": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsManagedPayments": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsNameCollection": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsNameCollectionBusiness": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsNameCollectionIndividual": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsOptionalItem": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsOptionalItemAdjustableQuantity": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentIntentData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentIntentDataShipping": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentIntentDataShippingAddress": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentIntentDataTransferData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAcssDebit": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAffirm": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAfterpayClearpay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAlipay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAlma": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAmazonPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAuBecsDebit": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsBacsDebit": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsBacsDebitMandateOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsBancontact": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsBillie": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsBoleto": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCard": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCardInstallments": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCardRestrictions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCashapp": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCrypto": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCustomerBalance": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsDemoPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsEps": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsFpx": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsGiropay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsGrabpay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsIdeal": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsKakaoPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsKlarna": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsKlarnaSubscription": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsKonbini": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsKrCard": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsLink": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsMobilepay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsMultibanco": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsNaverPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsOxxo": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsP24": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPayByBank": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPayco": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPaynow": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPaypal": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPayto": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPaytoMandateOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPix": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPixMandateOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsRevolutPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsSamsungPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsSatispay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsScalapay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsSepaDebit": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsSepaDebitMandateOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsSofort": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsSunbit": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsSwish": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsTwint": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsUpi": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsUpiMandateOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsUsBankAccount": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsWechatPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPermissions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPhoneNumberCollection": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSavedPaymentMethodOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSetupIntentData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingAddressCollection": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOption": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOptionShippingRateData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimate": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimateMaximum": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimateMinimum": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOptionShippingRateDataFixedAmount": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataBillingCycleAnchorConfig": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataBillingMode": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataBillingModeFlexible": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataInvoiceSettings": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataInvoiceSettingsIssuer": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataPendingInvoiceItemInterval": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataTransferData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataTrialSettings": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataTrialSettingsEndBehavior": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsTaxIdCollection": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsWalletOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsWalletOptionsLink": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionExpireParams": (
        "stripe.params.checkout._session_expire_params",
        False,
    ),
    "SessionLineItemListParams": (
        "stripe.params.checkout._session_line_item_list_params",
        False,
    ),
    "SessionListLineItemsParams": (
        "stripe.params.checkout._session_list_line_items_params",
        False,
    ),
    "SessionListParams": (
        "stripe.params.checkout._session_list_params",
        False,
    ),
    "SessionListParamsCreated": (
        "stripe.params.checkout._session_list_params",
        False,
    ),
    "SessionListParamsCustomerDetails": (
        "stripe.params.checkout._session_list_params",
        False,
    ),
    "SessionModifyParams": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsCollectedInformation": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsCollectedInformationShippingDetails": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsCollectedInformationShippingDetailsAddress": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsLineItem": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsLineItemAdjustableQuantity": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsLineItemPriceData": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsLineItemPriceDataProductData": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsLineItemPriceDataRecurring": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOption": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOptionShippingRateData": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimate": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimateMaximum": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimateMinimum": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOptionShippingRateDataFixedAmount": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionRetrieveParams": (
        "stripe.params.checkout._session_retrieve_params",
        False,
    ),
    "SessionUpdateParams": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsCollectedInformation": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsCollectedInformationShippingDetails": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsCollectedInformationShippingDetailsAddress": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsLineItem": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsLineItemAdjustableQuantity": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsLineItemPriceData": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsLineItemPriceDataProductData": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsLineItemPriceDataRecurring": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOption": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOptionShippingRateData": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimate": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimateMaximum": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimateMinimum": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOptionShippingRateDataFixedAmount": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing import List, Union
from typing_extensions import Literal, NotRequired, TypedDict


class PersonalizationDesignRejectParams(TypedDict):
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    rejection_reasons: "PersonalizationDesignRejectParamsRejectionReasons"
    """
    The reason(s) the personalization design was rejected.
    """


class PersonalizationDesignRejectParamsRejectionReasons(TypedDict):
    card_logo: NotRequired[
        List[
            Union[
                Literal[
                    "geographic_location",
                    "inappropriate",
                    "network_name",
                    "non_binary_image",
                    "non_fiat_currency",
                    "other",
                    "other_entity",
                    "promotional_material",
                ],
                str,
            ]
        ]
    ]
    """
    The reason(s) the card logo was rejected.
    """
    carrier_text: NotRequired[
        List[
            Union[
                Literal[
                    "geographic_location",
                    "inappropriate",
                    "network_name",
                    "non_fiat_currency",
                    "other",
                    "other_entity",
                    "promotional_material",
                ],
                str,
            ]
        ]
    ]
    """
    The reason(s) the carrier text was rejected.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_object import UntypedStripeObject
from typing import Dict, List
from typing_extensions import NotRequired, TypedDict


class MeterEventStreamCreateParams(TypedDict):
    events: List["MeterEventStreamCreateParamsEvent"]
    """
    List of meter events to include in the request. Supports up to 100 events per request.
    """


class MeterEventStreamCreateParamsEvent(TypedDict):
    event_name: str
    """
    The name of the meter event. Corresponds with the `event_name` field on a meter.
    """
    identifier: NotRequired[str]
    """
    A unique identifier for the event. If not provided, one will be generated.
    We recommend using a globally unique identifier for this. We'll enforce
    uniqueness within a rolling 24 hour period.
    """
    payload: "Dict[str, str]|UntypedStripeObject[str]"
    """
    The payload of the event. This must contain the fields corresponding to a meter's
    `customer_mapping.event_payload_key` (default is `stripe_customer_id`) and
    `value_settings.event_payload_key` (default is `value`). Read more about
    the
    [payload](https://docs.stripe.com/billing/subscriptions/usage-based/recording-usage#payload-key-overrides).
    """
    timestamp: NotRequired[str]
    """
    The time of the event. Must be within the past 35 calendar days or up to
    5 minutes in the future. Defaults to current timestamp if not specified.
    """
